@@ -276,7 +276,7 @@ def _get_service_status_code(instance):
 def _get_service_logs(instance):
     """Get logs for the cfy_manager_install_<type> service."""
     result = instance.run_command(
-        'journalctl -u {} 2>&1'.format(instance.unit_name),
+        'journalctl --no-pager -u {} 2>&1'.format(instance.unit_name),
         use_sudo=True, hide_stdout=True, ignore_failure=True)
     return result.stdout
 
@@ -390,16 +390,15 @@ def _install_instances(instances_dict, verbose):
                 instance.config_path), use_sudo=True)
 
             install_cmd = (
-                'systemd-run --unit {unit_name} --uid {user_name} '
+                # This runs with -t so that it blocks AND we see the logs as
+                # the command runs.
+                'systemd-run -t --unit {unit_name} --uid {user_name} '
                 'cfy_manager install -c {config} {verbose}'.format(
                     config=instance.config_path, unit_name=instance.unit_name,
                     user_name=getuser(), verbose='-v' if verbose else ''))
 
             instance.run_command(install_cmd, use_sudo=True)
             _verify_cloudify_installed_successfully(instance)
-            instance.run_command('cp {0} {1}'.format(
-                '/etc/cloudify/config.yaml', instance.config_path),
-                use_sudo=True)
 
 
 def _sort_instances_dict(instances_dict):
